@@ -10,6 +10,8 @@
 #include <QHash>
 #include <QObject>
 
+#include <functional>
+
 class QNetworkAccessManager;
 
 namespace KPkPass {
@@ -23,6 +25,8 @@ public:
     explicit PkPassManager(QObject *parent = nullptr);
     ~PkPassManager() override;
 
+    void setNetworkAccessManagerFactory(const std::function<QNetworkAccessManager*()> &namFactory);
+
     QVector<QString> passes() const;
 
     Q_INVOKABLE KPkPass::Pass* pass(const QString &passId);
@@ -39,6 +43,8 @@ public:
     QDateTime updateTime(const QString &passId) const;
 
     static QDateTime relevantDate(KPkPass::Pass *pass);
+    /** Check whether @p pass can be online updated. */
+    static bool canUpdate(KPkPass::Pass *pass);
 
     /** Raw pass file data, used for exporting. */
     QByteArray rawData(const QString &passId) const;
@@ -53,10 +59,8 @@ private:
     void importPassFromTempFile(const QUrl &tmpFile);
     QString doImportPass(const QUrl &url, const QByteArray &data, ImportMode mode);
 
-    QNetworkAccessManager *nam();
-
     QHash<QString, KPkPass::Pass*> m_passes;
-    QNetworkAccessManager *m_nam = nullptr;
+    std::function<QNetworkAccessManager*()> m_namFactory;
 };
 
 #endif // PKPASSMANAGER_H
