@@ -46,6 +46,7 @@ public:
 
     /** Same as the above, but usable from QML. */
     Q_INVOKABLE QVariant trainStationFromLocation(const KPublicTransport::Location &loc) const;
+    Q_INVOKABLE QVariant busStationFromLocation(const KPublicTransport::Location &loc) const;
 
     /** Applies information from @p location to the given KItinerary place.
      *  Unlike mergeStation(), this does not assume both sides refer to the same location, and @p location has precedence.
@@ -72,9 +73,9 @@ public:
     static QVariant mergeArrival(const QVariant &res, const KPublicTransport::Stopover &arr);
     static QVariant mergeJourney(const QVariant &res, const KPublicTransport::JourneySection &journey);
 
-    /** Checks if the given reservation and journey section have a compatible mode of transportation. */
-    static bool isSameMode(const QVariant &res, KPublicTransport::Line::Mode mode);
-    static bool isSameMode(const QVariant &res, const KPublicTransport::JourneySection &section);
+    /** Checkes whether @p mode is a train or bus mode respectively. */
+    static bool isTrainMode(KPublicTransport::Line::Mode mode);
+    static bool isBusMode(KPublicTransport::Line::Mode mode);
 
     /** Provide an icon source for usage in Kirigami.Icon that represents the line mode.
      *  This can be an official line logo, and official product logo or a generic mode icon,
